@@ -4,6 +4,7 @@ package App::Music::ChordPro::Config;
 
 use strict;
 use warnings;
+use App::Packager;
 
 =head1 NAME
 
@@ -167,6 +168,14 @@ This is the current built-in configuration file, showing all settings.
             },
 	},
   
+	// Markup for sections (in progress).
+  	// Define what to do with begin_of_XXX directives.
+  	// Use fallback as fallback.
+  	// Default is to ignore them.
+  	"section" : {
+  	    // "fallback" : "comment",
+  	},
+  
 	// This opens a margin for margin labels.
 	"labels" : {
 	    // Margin width. Default is 0 (no margin labels).
@@ -270,7 +279,18 @@ This is the current built-in configuration file, showing all settings.
   	    },
   	    "comment" : {
   		"name" : "Helvetica",
-  		"size" : 12
+  		"size" : 12,
+		"background" : "#E5E5E5"
+  	    },
+  	    "comment_italic" : {
+  		"name" : "HelveticaOblique",
+  		"size" : 12,
+		"background" : "#E5E5E5"
+  	    },
+  	    "comment_box" : {
+  		"name" : "Helvetica",
+  		"size" : 12,
+		"frame" : 1
   	    },
   	    "tab" : {
   		"name" : "Courier",
@@ -548,7 +568,7 @@ sub add_config {
 	    foreach my $c ( @{ delete $new->{include} } ) {
 		# Check for resource names.
 		if ( $c !~ m;[/.]; ) {
-		    my $t = ::findlib( "config/".lc($c).".json" );
+		    my $t = findresource( "config/".lc($c).".json" );
 		    $c = $t if $t;
 		}
 		elsif ( $dir ne ""
@@ -657,7 +677,9 @@ sub hmerge($$$) {
         }
         else {
 	    warn("Config error: unknown item $path$key\n")
-	      unless exists $res{$key};
+	      unless exists $res{$key}
+		|| $path.$key =~ /^pdf\.section\./;
+		;
             $res{$key} = $right->{$key};
         }
     }
