@@ -8,6 +8,7 @@ use strict;
 use warnings;
 use Data::Dumper;
 use Encode qw( encode_utf8 );
+use App::Packager;
 
 use App::Music::ChordPro::Output::Common;
 
@@ -540,6 +541,7 @@ sub generate_song {
     my $grid_barwidth = 0.5 * $fonts->{chord}->{size};
     my $grid_margin;
     my $did = 0;
+    my $curctx = "";
 
     while ( @elts ) {
 	$elt = shift(@elts);
@@ -580,6 +582,28 @@ sub generate_song {
 	     or $elt->{type} eq "tabline"
 	     or $elt->{type} =~ /^comment(?:_box|_italic)?$/ ) {
 
+	    if ( $elt->{context} ne $curctx ) {
+		$curctx = $elt->{context};
+		if ( $curctx ne "" ) {
+		    # Context switch.
+		    my $markup = $ps->{section}->{$curctx}
+		      || $ps->{section}->{fallback} || "";
+		    # If we have markup, insert a comment line.
+		    if ( $ps->{fonts}->{$markup} ) {
+			my $e = { type => "comment",
+				  font => $ps->{fonts}->{$markup},
+				  context => $curctx,
+				  orig => $curctx,
+				  text => ucfirst($curctx) };
+			unshift( @elts, $e, $elt );
+			redo;
+		    }
+		    elsif ( $markup ) {
+			warn( "Unhandled section markup: $markup\n");
+		    }
+		}
+	    }
+
 	    my $fonts = $ps->{fonts};
 	    my $type   = $elt->{type};
 
@@ -617,6 +641,7 @@ sub generate_song {
 				$style->{bar}->{width},
 				$style->{bar}->{color} );
 		}
+		$curctx = "chorus";
 	    }
 
 	    # Substitute metadata in comments.
@@ -635,9 +660,11 @@ sub generate_song {
 	    # Comment decorations.
 
 	    $pr->setfont( $ftext );
+
+=begin xxx
+
 	    my $text = $elt->{text};
 	    my $w = $pr->strwidth( $text );
-	    my $x1 = $x + $w;
 
 	    # Draw background.
 	    my $bgcol = $ftext->{background};
@@ -662,7 +689,9 @@ sub generate_song {
 			     $ftext->{color} || "black" );
 	    }
 
-	    songline( $elt, $x0, $y, $ps, song => $s, indent => $indent );
+=cut
+
+	    songline( $elt, $x, $y, $ps, song => $s, indent => $indent );
 
 	    $y -= $vsp;
 	    $pr->show_vpos( $y, 1 ) if DEBUG_SPACING;
@@ -1000,7 +1029,7 @@ sub songline {
     $i_tag = "";
 
     if ( $type =~ /^comment/ ) {
-	$ftext = $fonts->{$type} || $fonts->{comment};
+	$ftext = $elt->{font} || $fonts->{$type} || $fonts->{comment};
 	$ytext  = $ytop - font_bl($ftext);
 	my $song   = $opts{song};
 	$x += $opts{indent} if $opts{indent};
@@ -1070,15 +1099,6 @@ sub songline {
 	my $chord = $elt->{chords}->[$_];
 	my $phrase = $elt->{phrases}->[$_];
 
-	if ( $fchord->{background} && $chord ne "" && !$chordscol ) {
-	    # Draw background.
-	    my $w1 = $pr->strwidth( $pre.$chord.$post, $fchord );
-	    my $w2 = $inlinechords ? 0 : $pr->strwidth(" ") /  2;
-	    $pr->rectxy( $x - $w2, $ytop, $x + $w1 - $w2,
-			 $ytop - $fchord->{size}, 1,
-			 $fchord->{background} );
-	}
-
 	if ( $chordscol && $chord ne "" ) {
 
 	    if ( $chordscapo ) {
@@ -1813,7 +1833,7 @@ sub configurator {
     }
 
     # Add font dirs.
-    for my $fontdir ( @{$pdf->{fontdir}}, ::findlib("fonts"), $ENV{FONTDIR} ) {
+    for my $fontdir ( @{$pdf->{fontdir}}, getresource("fonts"), $ENV{FONTDIR} ) {
 	next unless $fontdir;
 	if ( -d $fontdir ) {
 	    $pdfapi->can("addFontDirs")->($fontdir);
@@ -1834,6 +1854,9 @@ sub configurator {
     }
 
     # Sanitize, if necessary.
+    my $comment = { %{ $fonts->{comment} } };
+    delete( $comment->{background} );
+    delete( $comment->{frame} );
     $fonts->{subtitle}       ||= { %{ $fonts->{text}  } };
     $fonts->{comment_italic} ||= { %{ $fonts->{chord} } };
     $fonts->{comment_box}    ||= { %{ $fonts->{chord} } };
@@ -1841,9 +1864,9 @@ sub configurator {
     $fonts->{toc}	     ||= { %{ $fonts->{text}  } };
     $fonts->{empty}	     ||= { %{ $fonts->{text}  } };
     $fonts->{grid}           ||= { %{ $fonts->{chord} } };
-    $fonts->{grid_margin}    ||= { %{ $fonts->{comment} } };
-    $fonts->{diagram}        ||= { %{ $fonts->{comment} } };
-    $fonts->{diagram_base}   ||= { %{ $fonts->{comment} } };
+    $fonts->{grid_margin}    ||= { %{ $comment } };
+    $fonts->{diagram}        ||= { %{ $comment } };
+    $fonts->{diagram_base}   ||= { %{ $comment } };
     $fonts->{chordfingers}     = { name => 'ZapfDingbats' };
     $fonts->{subtitle}->{size}       ||= $fonts->{text}->{size};
     $fonts->{comment_italic}->{size} ||= $fonts->{text}->{size};
@@ -1933,7 +1956,6 @@ sub new {
     $self->{pdf}->{forcecompress} = 0 if $regtest;
     $self->{pdf}->mediabox( $ps->{papersize}->[0],
 			    $ps->{papersize}->[1] );
-#    $self->newpage($ps);
     %fontcache = () if $::__EMBEDDED__;
     $self;
 }
@@ -1956,6 +1978,32 @@ sub text {
 
     $self->setfont($font, $size);
 
+    # Handle decorations (background, box).
+    my $bgcol = $font->{background};
+    my $frame = $font->{frame};
+    if ( $bgcol || $frame ) {
+	my $w = $self->strwidth( $text );
+	my $vsp = $size * 1.1;
+	# Adjust for baseline.
+	my $y = $y + ( $size / ( 1 - $font->{font}->descender / $font->{font}->ascender ) );
+
+	# Draw background.
+	if ( $bgcol && $bgcol !~ /^no(?:ne)?$/i ) {
+	    $self->rectxy( $x - 2, $y + 2,
+			   $x + $w + 2, $y - $vsp, 3, $bgcol );
+	}
+
+	# Draw box.
+	if ( $frame && $frame !~ /^no(?:ne)?$/i ) {
+	    my $x0 = $x;
+	    $x0 -= 0.25;	# add some offset for the box
+	    $self->rectxy( $x0, $y + 1,
+			   $x0 + $w + 1, $y - $vsp + 1,
+			   0.5, undef,
+			   $font->{color} || "black" );
+	}
+    }
+
     if ( $font->{color} ) {
 	$self->{pdftext}->strokecolor( $font->{color} );
 	$self->{pdftext}->fillcolor( $font->{color} );
@@ -2107,11 +2155,6 @@ sub newpage {
     $self->{pdftext} = $self->{pdfpage}->text;
 }
 
-sub add {
-    my ( $self, @text ) = @_;
-#    prAdd( "@text" );
-}
-
 sub finish {
     my ( $self, $file ) = @_;
 
